// params.cc

#include "params.h"
#include <iostream>
#include <cstdlib>

#include <iostream>
#include <ctime>

namespace CommonTilton
{

 // Constructor
  Params::Params(const string& value)
  {
    version = value;

    output_type = 2;
    mask_value_flag = false;
    mask_logic = 2;
    output_image_flag = false;

    return;
  }

 // Destructor...
  Params::~Params() 
  {
    return;
  }

 // Print version
  void Params::print_version( )
  {
    cout << endl << version << endl << endl;

    return;
  }

 // Read parameters
  bool Params::read(const char *param_file)
  {
//    cout << "Reading parameters from " << param_file << endl;
    ifstream param_fs(param_file);
    if (!param_fs.is_open())
    {
      cout << "Cannot open input file " << param_file << endl;
      return false;
    }

  // Read initial parameters from parameter file until End-of-File reached
    bool input_image_flag = false;
    bool output_mask_image_flag = false;
    int sub_pos;
    string line, sub_string;
    while (!param_fs.eof())
    {
      getline(param_fs,line);
      sub_pos = line.find("-");
      while ((!param_fs.eof()) && (sub_pos != 0))
      {
        getline(param_fs,line);
        sub_pos = line.find("-");
      }
      if (line.find("-input_image") != string::npos)
      {
        input_image_file = process_line(line,false);
        input_image_flag = true;
      }
      if (line.find("-output_type") != string::npos)
      {
        sub_string = process_line(line,false);
        output_type = atoi(sub_string.c_str());
      }
      if (line.find("-mask_logic") != string::npos)
      {
        sub_string = process_line(line,false);
        mask_logic = atoi(sub_string.c_str());
      }
      if (line.find("-mask_value") != string::npos)
      {
        sub_string = process_line(line,false);
        mask_value = atoi(sub_string.c_str());
        mask_value_flag = true;
      }
      if (line.find("-output_image") != string::npos)
      {
        output_image_file = process_line(line,false);
        output_image_flag = true;
      }
      if (line.find("-output_mask_image") != string::npos)
      {
        output_mask_image_file = process_line(line,false);
        output_mask_image_flag = true;
      }
    }

    param_fs.close();

// Exit with false status if a required parameter is not set, or an improper parameter
// setting is detected.
    if (!input_image_flag)
    {
      cout << "ERROR: -input_image (Input image file) is required" << endl;
      return false;
    }
    if ((output_type < 1) or (output_type > 2))
    {
      cout << "ERROR: Invalid output_type (output type). -output_type must be 1 or 2" << endl;
      return false;
    }
    if (!output_mask_image_flag)
    {
      cout << "ERROR: -output_mask_image (Output mask image file) is required" << endl;
      return false;
    }

    return true;
  }

 // Print parameters
  void Params::print()
  {
  // Print version
      cout << "This is " << version << endl << endl;

  // Print input parameters
      cout << "Input image file name: " << input_image_file << endl;
      switch (output_type)
      {
        case 1:  cout << "Requested multispectral mask" << endl;
                 break;
        case 2:  cout << "Requested single combined mask" << endl;
                 break;
        default: cout << "WARNING: Invalid output_type" << endl;
                 break;
      }
      switch (mask_logic)
      {
        case 1:  cout << "Requested AND logic" << endl;
                 break;
        case 2:  cout << "Requested OR logic" << endl;
                 break;
        default: cout << "WARNING: Invalid mask_logic" << endl;
                 break;
      }
      if (mask_value_flag)
        cout << "Mask value = " << mask_value << endl;
      if (output_image_flag)
        cout << "Output image file name: " << output_image_file << endl;
      cout << "Output mask image file name: " << output_mask_image_file << endl;

      return;
  }

  string process_line(const string& line, const bool& list_flag)
  {
    int sub_pos, sub_pos_space, sub_pos_tab;
    string sub_string;

    sub_pos_space = line.find_first_of(" ");
    sub_pos_tab = line.find_first_of("\t");
    sub_pos = sub_pos_space;
    if (sub_pos ==  (int) string::npos)
      sub_pos = sub_pos_tab;
    if (sub_pos ==  (int) string::npos)
      return " ";

    sub_string = line.substr(sub_pos);
    while ((sub_string.substr(0,1) == "\t") || (sub_string.substr(0,1) == " "))
      sub_string = line.substr(++sub_pos);
#ifndef WINDOWS
    if (list_flag)
      return sub_string;

    sub_pos = sub_string.find_first_of(" ");
    if (sub_pos !=  (int) string::npos)
      sub_string = sub_string.substr(0,sub_pos);
    sub_pos = sub_string.find_first_of("\t");
    if (sub_pos !=  (int) string::npos)
      sub_string = sub_string.substr(0,sub_pos);
    sub_pos = sub_string.find_first_of("\r");
    if (sub_pos !=  (int) string::npos)
      sub_string = sub_string.substr(0,sub_pos);
#endif
    return sub_string;
  }

} // namespace CommonTilton
