// params.cc

#include "params.h"
#include <iostream>

namespace CommonTilton
{

 // Constructor
  Params::Params(const string& value)
  {
    version = value;

    return;
  }

 // Destructor...
  Params::~Params() 
  {
    return;
  }

 // Print version
  void Params::print_version( )
  {
    cout << endl << version << endl << endl;

    return;
  }

 // Read parameters
  bool Params::read(const char *param_file)
  {
//    cout << "Reading parameters from " << param_file << endl;
    ifstream param_fs(param_file);
    if (!param_fs.is_open())
    {
      cout << "Cannot open input file " << param_file << endl;
      return false;
    }

  // Read initial parameters from parameter file until End-of-File reached
    bool input_log_flag = false;
    bool prefix_flag = false;
    bool suffix_flag = false;
    bool output_log_flag = false;
    int sub_pos;
    string line, sub_string;
    while (!param_fs.eof())
    {
      getline(param_fs,line);
      sub_pos = line.find("-");
      while ((!param_fs.eof()) && (sub_pos != 0))
      {
        getline(param_fs,line);
        sub_pos = line.find("-");
      }
      if (line.find("-input_log_files") != string::npos)
      {
        input_log_files = process_line(line,false);
        input_log_flag = true;
      }
      if (line.find("-prefix") != string::npos)
      {
        prefix = process_line(line,false);
        prefix_flag = true;
      }
      if (line.find("-suffix") != string::npos)
      {
        suffix = process_line(line,false);
        suffix_flag = true;
      }
      if (line.find("-output_log_file") != string::npos)
      {
        output_log_file = process_line(line,false);
        output_log_flag = true;
      }
    }

    param_fs.close();

// Exit with false status if a required parameter is not set, or an improper parameter
// setting is detected.
    if (!input_log_flag)
    {
      cout << "ERROR: -input_log_files (Name of the input file containing the output log files from the hsegrefcomp program) is required" << endl;
      return false;
    }
    if (!prefix_flag)
    {
      cout << "ERROR: -prefix (Prefix of the hsegrefcomp output log filenamess) is required" << endl;
      return false;
    }
    if (!suffix_flag)
    {
      cout << "ERROR: -suffix (Suffix of the hsegrefcomp output log filenames) is required" << endl;
      return false;
    }
    if (!output_log_flag)
    {
      cout << "ERROR: -output_log_file (Output log file) is required" << endl;
      return false;
    }
 
    return true;
  }

 // Print parameters
  void Params::print()
  {
  // Print version
      cout << "This is " << version << endl << endl;

  // Print input parameters
      cout << "Name of the input file containing the hsegrefcomp output log file names: " << input_log_files << endl;
      cout << "Log file names prefix: " << prefix << endl;
      cout << "Log file names suffix: " << suffix << endl;
      cout << "Output log file name: " << output_log_file << endl;

      return;
  }

  string process_line(const string& line, const bool& list_flag)
  {
    int sub_pos, sub_pos_space, sub_pos_tab;
    string sub_string;

    sub_pos_space = line.find_first_of(" ");
    sub_pos_tab = line.find_first_of("\t");
    sub_pos = sub_pos_space;
    if (sub_pos ==  (int) string::npos)
      sub_pos = sub_pos_tab;
    if (sub_pos ==  (int) string::npos)
      return " ";

    sub_string = line.substr(sub_pos);
    while ((sub_string.substr(0,1) == "\t") || (sub_string.substr(0,1) == " "))
      sub_string = line.substr(++sub_pos);
#ifndef WINDOWS
    if (list_flag)
      return sub_string;

    sub_pos = sub_string.find_first_of(" ");
    if (sub_pos !=  (int) string::npos)
      sub_string = sub_string.substr(0,sub_pos);
    sub_pos = sub_string.find_first_of("\t");
    if (sub_pos !=  (int) string::npos)
      sub_string = sub_string.substr(0,sub_pos);
    sub_pos = sub_string.find_first_of("\r");
    if (sub_pos !=  (int) string::npos)
      sub_string = sub_string.substr(0,sub_pos);
#endif
    return sub_string;
  }

} // namespace CommonTilton
